## INTRODUCTION

The CryptoCurrency module integrates with cryptocurrency exchanges using the CCXT library to track and manage market pairs and balances.

The primary use case for this module is:

- Configure and track cryptocurrency market pairs
- Monitor exchange rates between different cryptocurrencies
- Track balances across multiple exchanges
- Manage which exchanges and currency pairs to track

## REQUIREMENTS

This module requires the following:
- Drupal 10 or higher
- PHP 8.0 or higher with the following extensions:
  * gmp (for large number operations)
- CCXT library (`composer require ccxt/ccxt`)
- Key module (`composer require drupal/key`)
- Barcodes module (`composer require drupal/barcodes`)
- Views module (included with Drupal core)

### DDEV Setup
If you're using DDEV for local development, add this PHP extension to your `.ddev/config.yaml`:
```yaml
webimage_extra_packages: ["php${DDEV_PHP_VERSION}-gmp"]
```

## INSTALLATION

Install as you would normally install a contributed Drupal module.
See: https://www.drupal.org/node/895232 for further information.
If you install this module with Composer (`composer require drupal/cc`), the dependencies will be installed automatically.

## CONFIGURATION

1. Navigate to [Configuration > Web services > Currency Exchange](/admin/config/services/cc-exchange)
2. Select the exchanges you want to use:
   - you can use any with public APIs (eg. for reading market prices) even without creating accounts (rate limits may apply)
   - pick the ones you have an account with to use their private API methods (eg. for querying your balances and trading)
3. Choose which currencies you want to track:
   - Accepted currencies: the currencies you receive in your shop and that you may want to sell
   - Needed currencies: the currencies you spend for operating your shop and that you may want to buy
4. Configure API keys for each exchange:
   - Go to Configuration > System > Keys to add your API keys
   - Create two keys for each exchange:
     * Public API Key: The API key from your exchange
     * Private API Secret: The API secret from your exchange
   - Set both keys as "Authentication" type
   - Store them securely using your preferred key provider
5. Go to the [API Keys tab](/admin/config/services/cc-exchange/api-keys) to link the keys to each enabled exchange.

## USAGE

### Market Pairs

1. View available [Market Pairs](/admin/config/services/cc-exchange/market-pairs)
2. The page shows current prices for all active currency pairs that result from your selection of currencies and exchanges (only direct pairs of "accepted" and "needed"currencies are considered atm)
3. Use the "Refresh Prices" button to get latest rates
4. Use "Refresh Available Markets" to update the list of available pairs

### Exchange Balances

1. View your [Exchange Balances](/admin/config/services/cc-exchange/balances)
2. The page shows your current balances across all configured exchanges
3. Only non-zero balances are displayed
4. Balances are cached for performance - click "Refresh Balances" button when you need updated data

## MAINTAINERS

Current maintainers:
- kopeboy (https://www.drupal.org/u/kopeboy)
